# remirepo spec file for php-ast
#
# SPDX-FileCopyrightText:  Copyright 2015-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-ast}

%global pecl_name   ast
%global pie_vend    nikic
%global pie_proj    php-ast
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
# After 20-tokenizer.ini
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       Abstract Syntax Tree
Name:          %{?scl_prefix}php-ast
Version:       1.1.2
Release:       2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       BSD-3-Clause
URL:           https://pecl.php.net/package/ast
Source0:       http://pecl.php.net/get/%{sources}.tgz

Patch0:        php85.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.2
BuildRequires: %{?scl_prefix}php-pear
BuildRequires: %{?scl_prefix}php-tokenizer

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
Requires:      %{?scl_prefix}php-tokenizer%{?_isa}

# PECL/PIE
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj} = %{version}


%description
This extension exposes the abstract syntax tree generated by PHP 7.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_AST_VERSION/{s/.* "//;s/".*$//;p}' php_ast.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
    --enable-ast
%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
    --enable-ast
%make_build
%endif


%install
%{?dtsenable}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the NTS stuff
%make_install -C NTS
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done



%check
cd %{sources}
VER=$(%{__php} -r 'echo PHP_VERSION_ID;')
OPT="-P -q --show-diff"
if [ $VER -ge 70400 ]; then
  OPT="$OPT %{?_smp_mflags}"
fi

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

: Upstream test suite  for NTS extension
TEST_PHP_ARGS="-n -d extension=tokenizer.so -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php $OPT

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

: Upstream test suite  for ZTS extension
TEST_PHP_ARGS="-n -d extension=tokenizer.so -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php $OPT
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Jul  4 2025 Remi Collet <remi@remirepo.net> - 1.1.2-2
- fix for PHP 8.5 using patch from upstream and from
  https://github.com/nikic/php-ast/pull/253

* Mon Aug 12 2024 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Mon Nov 13 2023 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1

* Mon Oct  2 2023 Remi Collet <remi@remirepo.net> - 1.1.0-4
- ignore 4 test failing with 8.3

* Wed Mar 15 2023 Remi Collet <remi@remirepo.net> - 1.1.0-3
- build out of sources tree

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 1.1.0-2
- rebuild for PHP 8.2.0RC1

* Wed Aug 10 2022 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- raise dependency on PHP 7.2

* Sun Nov 28 2021 Remi Collet <remi@remirepo.net> - 1.0.16-1
- update to 1.0.16

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.0.14-2
- rebuild for 8.1.0RC1

* Sun Jul 25 2021 Remi Collet <remi@remirepo.net> - 1.0.14-1
- update to 1.0.14

* Thu Jul  8 2021 Remi Collet <remi@remirepo.net> - 1.0.13-1
- update to 1.0.13

* Mon May 17 2021 Remi Collet <remi@remirepo.net> - 1.0.12-1
- update to 1.0.12

* Tue Apr 20 2021 Remi Collet <remi@remirepo.net> - 1.0.11-1
- update to 1.0.11

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.0.10-3
- rebuild for PHP 8.0.0RC1

* Wed Sep 16 2020 Remi Collet <remi@remirepo.net> - 1.0.10-2
- open https://github.com/nikic/php-ast/issues/187 failed test
  with 8.0.0beta4

* Sun Sep 13 2020 Remi Collet <remi@remirepo.net> - 1.0.10-1
- update to 1.0.10

* Fri Sep  4 2020 Remi Collet <remi@remirepo.net> - 1.0.9-1
- update to 1.0.9
- drop patch merged upstream

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.0.8-2
- add patch for 8.0.0beta3 from
  https://github.com/nikic/php-ast/pull/174

* Thu Aug  6 2020 Remi Collet <remi@remirepo.net> - 1.0.8-1
- update to 1.0.8

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 1.0.7-4
- rebuild for 8.0.0beta1

* Fri Jul 24 2020 Remi Collet <remi@remirepo.net> - 1.0.7-3
- EL-8 rebuild

* Tue Jul 21 2020 Remi Collet <remi@remirepo.net> - 1.0.7-2
- add patch from https://github.com/nikic/php-ast/pull/165
  relax tests for 8.0.0alpha3

* Sun Jul 12 2020 Remi Collet <remi@remirepo.net> - 1.0.7-1
- update to 1.0.7

* Sun Feb 23 2020 Remi Collet <remi@remirepo.net> - 1.0.6-1
- update to 1.0.6

* Wed Nov 27 2019 Remi Collet <remi@remirepo.net> - 1.0.5-1
- update to 1.0.5

* Tue Nov 12 2019 Remi Collet <remi@remirepo.net> - 1.0.4-1
- update to 1.0.4

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.0.3-2
- rebuild for 7.4.0RC1

* Mon Jul 29 2019 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3

* Mon Jul  1 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Mon Feb 11 2019 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Mon Oct 22 2018 Remi Collet <remi@remirepo.net> - 1.0.0-2
- add missing scriptlets

* Mon Oct 22 2018 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Sun Oct  7 2018 Remi Collet <remi@remirepo.net> - 0.1.7-1
- update to 0.1.7

* Tue Aug 21 2018 Remi Collet <remi@remirepo.net> - 0.1.6-4
- ignore 1 failed test with 7.3

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.1.6-3
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.1.6-2
- rebuld for 7.3.0alpha4 new ABI

* Mon Oct  9 2017 Remi Collet <remi@remirepo.net> - 0.1.6-1
- Update to 0.1.6

* Tue Aug  1 2017 Remi Collet <remi@remirepo.net> - 0.1.5-1
- update to 0.1.5 (stable)
- sources from PECL

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.1.4-4
- rebuild for PHP 7.2.0beta2 new API

* Wed Mar 29 2017 Remi Collet <remi@remirepo.net> - 0.1.4-3
- add upstream patch for PHP 7.1.4RC1, fix FTBFS detected by Koschei

* Thu Jan 26 2017 Remi Collet <remi@fedoraproject.org> - 0.1.4-1
- update to 0.1.4

* Thu Jan 19 2017 Remi Collet <remi@fedoraproject.org> - 0.1.3-1
- update to 0.1.3

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.1.2-4
- rebuild with PHP 7.1.0 GA

* Fri Nov 25 2016 Remi Collet <remi@fedoraproject.org> - 0.1.2-3
- fix LICENSE, drop empty file, from review #1398355
- add upstream patch for php 7.1

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.1.2-2
- rebuild for PHP 7.1 new API version

* Fri Aug  5 2016 Remi Collet <remi@fedoraproject.org> - 0.1.2-1
- update to 0.1.2

* Fri Jun 10 2016 Remi Collet <remi@fedoraproject.org> - 0.1.2-0.1.20160608gitb8f5805
- update to 0.1.2-dev for PHP 7.1

* Thu Jan  7 2016 Remi Collet <remi@fedoraproject.org> - 0.1.1-1
- update to 0.1.1

* Thu Oct 29 2015 Remi Collet <remi@fedoraproject.org> - 0.1.0-0.2.20151021gitac969d7
- add dependency on php-tokenizer, fix test suite

* Wed Oct 28 2015 Remi Collet <remi@fedoraproject.org> - 0.1.0-0.1.20151021gitac969d7
- new package, version 0.1.0dev
